summaryrefslogtreecommitdiffstats
path: root/libavcodec/avcodec.h
diff options
context:
space:
mode:
Diffstat (limited to 'libavcodec/avcodec.h')
-rw-r--r--libavcodec/avcodec.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/libavcodec/avcodec.h b/libavcodec/avcodec.h
index f720589..df061c1 100644
--- a/libavcodec/avcodec.h
+++ b/libavcodec/avcodec.h
@@ -2987,13 +2987,13 @@ typedef struct AVHWAccel {
int (*end_frame)(AVCodecContext *avctx);
/**
* Size of HW accelerator private data.
*
* Private data is allocated with av_mallocz() before
* AVCodecContext.get_buffer() and deallocated after
* AVCodecContext.release_buffer().
*/
- int priv_data_size;
+ int frame_priv_data_size;
} AVHWAccel;
/**
OpenPOWER on IntegriCloud
@@ -2987,13 +2987,13 @@ typedef struct AVHWAccel {
int (*end_frame)(AVCodecContext *avctx);
/**
- * Size of HW accelerator private data.
+ * Size of per-frame hardware accelerator private data.
*
* Private data is allocated with av_mallocz() before